@@ -15,6 +15,10 @@ from time import sleep
 import xml.etree.ElementTree
 from typing import Optional, Any, Generator, Dict, Tuple
 
+import pygal
+from pygal import Config
+from pygal.style import DarkStyle, LightStyle, BlueStyle
+
 from pyPreservica.common import *
 
 logger = logging.getLogger(__name__)
@@ -1481,7 +1485,7 @@ class EntityAPI(AuthenticatedAPI):
                 yield from self.all_descendants(folder=e.reference)
 
     def descendants(self, folder: Any = None) -> Generator:
-        maximum = 25
+        maximum = 100
         paged_set = self.children(folder, maximum=maximum, next_page=None)
         for entity in paged_set.results:
             yield entity
@@ -1490,24 +1494,26 @@ class EntityAPI(AuthenticatedAPI):
             for entity in paged_set.results:
                 yield entity
 
-    def children(self, folder: Any = None, maximum: int = 50, next_page: str = None) -> PagedSet:
+    def children(self, folder: Any = None, maximum: int = 100, next_page: str = None) -> PagedSet:
         headers = {HEADER_TOKEN: self.token}
         data = {'start': str(0), 'max': str(maximum)}
         folder_reference = folder
         if next_page is None:
             if folder_reference is None:
-                request = self.session.get(f'https://{self.server}/api/entity/root/children', data=data,
+                request = self.session.get(f'https://{self.server}/api/entity/root/children', params=data,
                                            headers=headers)
             else:
                 if hasattr(folder, "reference"):
                     folder_reference = folder.reference
                 request = self.session.get(
                     f'https://{self.server}/api/entity/structural-objects/{folder_reference}/children',
-                    data=data, headers=headers)
+                    params=data, headers=headers)
         else:
             request = self.session.get(next_page, headers=headers)
+        logger.debug(request.url)
         if request.status_code == requests.codes.ok:
             xml_response = str(request.content.decode('utf-8'))
+            logger.debug(xml_response)
             entity_response = xml.etree.ElementTree.fromstring(xml_response)
             children = entity_response.findall(f'.//{{{self.entity_ns}}}Child')
             result = set()
@@ -1533,6 +1539,21 @@ class EntityAPI(AuthenticatedAPI):
         else:
             raise RuntimeError(request.status_code, "children failed")
 
+    def all_ingest_events(self, previous_days: int = 1) -> Generator:
+        self.token = self.__token__()
+        previous = datetime.utcnow() - timedelta(days=previous_days)
+        from_date = previous.replace(tzinfo=timezone.utc).isoformat()
+        to_date = datetime.utcnow().replace(tzinfo=timezone.utc).isoformat()
+        paged_set = self._all_events_page(maximum=25, next_page=None, type="Ingest", from_date=from_date,
+                                          to_date=to_date)
+        for entity in paged_set.results:
+            yield entity
+        while paged_set.has_more:
+            paged_set = self._all_events_page(maximum=25, next_page=paged_set.next_page, type="Ingest",
+                                              from_date=from_date, to_date=to_date)
+            for entity in paged_set.results:
+                yield entity
+
     def all_events(self) -> Generator:
         self.token = self.__token__()
         paged_set = self._all_events_page()
@@ -1548,7 +1569,15 @@ class EntityAPI(AuthenticatedAPI):
           event actions performed against this repository
          """
         headers = {HEADER_TOKEN: self.token}
+
         params = {'start': str(0), 'max': str(maximum)}
+        if "type" in kwargs:
+            params["types"] = kwargs.get("type")
+        if "from_date" in kwargs:
+            params["from"] = kwargs.get("from_date")
+        if "to_date" in kwargs:
+            params["to"] = kwargs.get("to_date")
+
         if next_page is None:
             request = self.session.get(f'https://{self.server}/api/entity/events', params=params, headers=headers)
         else:
@@ -1679,7 +1708,7 @@ class EntityAPI(AuthenticatedAPI):
 
     def updated_entities(self, previous_days: int = 1) -> Generator:
         self.token = self.__token__()
-        maximum = 50
+        maximum = 25
         paged_set = self._updated_entities_page(previous_days=previous_days, maximum=maximum, next_page=None)
         for entity in paged_set.results:
             yield entity
