@@ -1393,7 +1393,7 @@ class UploadAPI(AuthenticatedAPI):
          :param str path_to_zip_package: Path to the package
          :param str bucket_name: Bucket connected to an ingest workflow
          :param Folder folder: The folder to ingest the package into
-         :param str callback: Optional callback to allow the callee to monitor the upload progress
+         :param Callable callback: Optional callback to allow the callee to monitor the upload progress
          :param bool delete_after_upload: Delete the local copy of the package after the upload has completed
 
         """
